searchNodes=[{"type":"module","title":"Cldr.Collation","doc":"Implements the Unicode collation rules based on the CLDR root collation which in turn is based upon the Unicode DUCET table.","ref":"Cldr.Collation.html"},{"type":"function","title":"Cldr.Collation.compare/3","doc":"Compares two strings according to the Unicode collation rules with the CLDR root collation which is based upon the Unicode DUCET table. Arguments string_1 is an a String.t/0 string_2 is an a String.t/0 options is a keyword list of options Options :casing is either :sensitive or :insensitive indicating if collation is to be case sensitive or not. The default is :insensitive . Returns Either of :lt , :eq or :gt signifying if string_1 is less than, equal to or greater than string_2 . Examples iex&gt; Cldr.Collation . compare &quot;á&quot; , &quot;A&quot; , casing : :sensitive :gt iex&gt; Cldr.Collation . compare &quot;á&quot; , &quot;A&quot; , casing : :insensitive :eq","ref":"Cldr.Collation.html#compare/3"},{"type":"function","title":"Cldr.Collation.init/0","doc":"","ref":"Cldr.Collation.html#init/0"},{"type":"function","title":"Cldr.Collation.sort/2","doc":"Sorts a list of strings according to the Unicode collation rules with the CLDR root collation which is based upon the Unicode DUCET table. This collation does not aim to provide precisely correct ordering for each language and script; tailoring would be required for correct language handling in almost all cases. The goal is instead to have all the other characters, those that are not tailored, show up in a reasonable order. Arguments strings is an enumerable of type t:String.t() options is a keyword list of options Options casing is either :sensitive or :insensitive indicating if collation is to be case sensitive or not. The default is :insensitive Returns An ordered list of t:String.t() Examples iex&gt; Cldr.Collation . sort [ &quot;á&quot; , &quot;b&quot; , &quot;A&quot; ] [ &quot;á&quot; , &quot;A&quot; , &quot;b&quot; ] iex&gt; Cldr.Collation . sort [ &quot;á&quot; , &quot;b&quot; , &quot;A&quot; ] , casing : :sensitive [ &quot;A&quot; , &quot;á&quot; , &quot;b&quot; ]","ref":"Cldr.Collation.html#sort/2"},{"type":"type","title":"Cldr.Collation.comparison/0","doc":"","ref":"Cldr.Collation.html#t:comparison/0"},{"type":"type","title":"Cldr.Collation.options/0","doc":"","ref":"Cldr.Collation.html#t:options/0"},{"type":"module","title":"Cldr.Collation.Insensitive","doc":"Compare two strings using the UCA in a case-insensitive manner","ref":"Cldr.Collation.Insensitive.html"},{"type":"function","title":"Cldr.Collation.Insensitive.compare/2","doc":"","ref":"Cldr.Collation.Insensitive.html#compare/2"},{"type":"module","title":"Cldr.Collation.Sensitive","doc":"Compare two strings using the UCA in a case-sensitive manner","ref":"Cldr.Collation.Sensitive.html"},{"type":"function","title":"Cldr.Collation.Sensitive.compare/2","doc":"","ref":"Cldr.Collation.Sensitive.html#compare/2"},{"type":"extras","title":"Cldr Collation","doc":"A NIF-based Unicode collator based upon the Unicode library libicu4c . Builds upon the erlang library erlang-ucol by Benoit Chesneau benoitc@e-engura.org and Nicolas Dufour nrdufour@gmail.com This initial version uses only the &quot;root&quot; locale collator which is the CLDR DUCET collator .","ref":"readme.html"},{"type":"extras","title":"Cldr Collation - Installation","doc":"ex_cldr_collation depends upon libicu to provide the underlying collator. There are two required components: At build time (compilation), the libicu development headers are are required. On MacOS these headers are provided as part of the library. For Linux systems the package typically called libicu-dev is required. At runtime the libicu library is required. On MacOS and Ubuntu this library is delivered as part of the OS. For Alpine and Debian the icu package needs to be installed. Installation on MacOS On MacOS, the relevant headers are included in ex_cldr_collation and no additional installation is required. Installation on Linux On Linux systems, libicu-dev , libicu and pkg-conf must be installed and well as basic development tools for the build process. # For Ubuntu # pkg-config and libicu are required for compiling the NIF # assumes libicu is already installed which is normal on Ubuntu $ sudo apt-get install pkgconf libicu-dev # For Debian # pkg-config and icu-dev are required when compiling the NIF # libicu is required at runtime # Debian Bullseye $ sudo apt install pkgconf libicu-dev libicu67 # Debian Bookworm $ sudo apt install pkgconf libicu-dev libicu72 # For Alpine # pkg-config and icu-dev are required when compiling the NIF # icu is required at runtime $ apk add pkgconf icu-dev icu # Then check that the libicu package dependencies # can be resolved $ pkg-config --libs icu-uc icu-io -licuio -licui18n -licuuc -licudata Installing ex_cldr_collation The package can then be installed by adding cldr_collation to your list of dependencies in mix.exs : def deps do [ { :ex_cldr_collation , &quot;~&gt; 0.7.0&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"Cldr Collation - Examples","doc":"# Sorting using Cldr.Collator.sort/2 iex&gt; Cldr.Collation . sort ( [ &quot;á&quot; , &quot;b&quot; , &quot;A&quot; ] , casing : :sensitive ) [ &quot;A&quot; , &quot;á&quot; , &quot;b&quot; ] iex&gt; Cldr.Collation . sort ( [ &quot;á&quot; , &quot;b&quot; , &quot;A&quot; ] , casing : :insensitive ) [ &quot;á&quot; , &quot;A&quot; , &quot;b&quot; ] # Comparing strings iex&gt; Cldr.Collation . compare ( &quot;a&quot; , &quot;A&quot; , casing : :insensitive ) :eq iex&gt; Cldr.Collation . compare ( &quot;a&quot; , &quot;A&quot; , casing : :sensitive ) :lt # Using Elixir 1.10 Enum.sort # Cldr.Collation.Sensitive, Cldr.Collation.Insensitive # comparise modules are provided iex&gt; Enum . sort ( [ &quot;AAAA&quot; , &quot;AAAa&quot; ] , Cldr.Collation.Insensitive ) [ &quot;AAAA&quot; , &quot;AAAa&quot; ] iex&gt; Enum . sort ( [ &quot;AAAA&quot; , &quot;AAAa&quot; ] , Cldr.Collation.Sensitive ) [ &quot;AAAa&quot; , &quot;AAAA&quot; ]","ref":"readme.html#examples"},{"type":"extras","title":"LICENSE","doc":"The Elixir code and additions to the NIF to handle configurable collators is copyright 2019 (c) Kip Cole kipcole9@gmail.com The original erlang NIF is copyright: 2011-2015 (c) BenoÃ®t Chesneau benoitc@e-engura.org 2011-2015 (c) Nicolas Dufour nrdufour@gmail.com Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.7.3","doc":"This is the changelog for Cldr_collation v0.7.3 released on May 28th, 2024. For older changelogs please consult the release tag on GitHub Bug fixes Fix compiler warnings for Elixir 1.17.","ref":"changelog.html#ex_cldr_collation-v0-7-3"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.7.2","doc":"This is the changelog for Cldr_collation v0.7.2 released on February 8th, 2023. For older changelogs please consult the release tag on GitHub Bug fixes Makes the Makefile more resilient by exiting if pkg-config isn't installed and therefore ICU_LIBS is empty. Previously this would fail silently and an unclear runtime error would be reported. Improved the error message if the NIF can't be loaded. Thanks to @linusdm. Closes #8.","ref":"changelog.html#ex_cldr_collation-v0-7-2"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.7.1","doc":"This is the changelog for Cldr_collation v0.7.1 released on February 24th, 2023. For older changelogs please consult the release tag on GitHub Bug fixes Add binary guards to Cldr.Collation.compare/3 .","ref":"changelog.html#ex_cldr_collation-v0-7-1"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.7.0","doc":"This is the changelog for Cldr_collation v0.7.0 released on January 4th, 2022. For older changelogs please consult the release tag on GitHub Bug fixes Fix the .so path for the NIF at load time, not compile time. Thanks to @sergiorjsd for the report. Closes #3. Fix buidling on ARM-based Mac models","ref":"changelog.html#ex_cldr_collation-v0-7-0"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.6.0","doc":"This is the changelog for Cldr_collation v0.6.0 released on July 3rd, 2021. For older changelogs please consult the release tag on GitHub Bug fixes Load the nif from a path relative to :code.priv_dir/1 .","ref":"changelog.html#ex_cldr_collation-v0-6-0"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.5.0","doc":"This is the changelog for Cldr_collation v0.5.0 released on June 23rd, 2021. For older changelogs please consult the release tag on GitHub Bug fixes Correctly reference the ucol.so file when loading at startup Removes unrequired dependencies Enhancements Adds Cldr.Collator.sort/2 Adds documentation for Cldr.Collator.compare/3","ref":"changelog.html#ex_cldr_collation-v0-5-0"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.4.0","doc":"This is the changelog for Cldr_collation v0.4.0 released on April 9th, 2021. For older changelogs please consult the release tag on GitHub Bug Fixes Fix compilation issues on OTP 23 and later. On these releases, liberl_interface.a doesn't exist and isn't required. Thanks to @zookzook for the report.","ref":"changelog.html#ex_cldr_collation-v0-4-0"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.3.0","doc":"This is the changelog for Cldr_collation v0.3.0 released on March 3rd, 2020. For older changelogs please consult the release tag on GitHub Enhancements Add :inets to :extra_applications for later versions of Elixir Fix application name in README.md . Thanks to @phlppn. Note the requirement for Elixir 1.10 or later in order to use the module-based comparators for Enum.sort/2 .","ref":"changelog.html#ex_cldr_collation-v0-3-0"},{"type":"extras","title":"Changelog - Ex_Cldr_Collation v0.2.0","doc":"This is the changelog for Cldr_collation v0.2.0 released on Match 13th, 2020. For older changelogs please consult the release tag on GitHub Enhancements Adds support for module-based comparators used by Enum.sort/2 on Elixir 1.10 and later. The comparitor modules are Cldr.Collator (which is case insensitive), Cldr.Collator.Sensitive (case sensitive comparison) and Cldr.Collator.Insensitive (case insensitive comparison).","ref":"changelog.html#ex_cldr_collation-v0-2-0"}]